==> service-common-2.9.2-20161205.023958-2-sources.jar: com/baijia/tianxiao/dto/mobile/AppAuthToken.java <==
package com.baijia.tianxiao.dto.mobile;


import com.baijia.tianxiao.dto.BaseDto;

/**
 * app登录token
 * @title AppAuthToken
 * @desc TODO 
 * @author zhangbing
 * @date 2015年4月18日
 * @version 1.0
 */
public class AppAuthToken extends BaseDto {

    private static final long serialVersionUID = -8364142680639211438L;

    private Long user_id;
    
    private Integer ct;
    
    private String salt;

    private Integer tx_cascade_user_id;

    private Integer tx_account_id;
    
    private Integer accountVersion;

    private String appEnv;

    public String getAppEnv() {
        return appEnv;
    }

    public void setAppEnv(String appEnv) {
        this.appEnv = appEnv;
    }

    public Long getUser_id() {
        return user_id;
    }

    public void setUser_id(Long user_id) {
        this.user_id = user_id;
    }

    public Integer getCt() {
        return ct;
    }

    public void setCt(Integer ct) {
        this.ct = ct;
    }

    public String getSalt() {
        return salt;
    }

    public void setSalt(String salt) {
        this.salt = salt;
    }

    public Integer getTx_cascade_user_id() {
    
        return tx_cascade_user_id;
    }

    public void setTx_cascade_user_id(Integer tx_cascade_user_id) {
    
        this.tx_cascade_user_id = tx_cascade_user_id;
    }

    public Integer getTx_account_id() {
    
        return tx_account_id;
    }

    public void setTx_account_id(Integer tx_account_id) {
    
        this.tx_account_id = tx_account_id;
    }

    public Integer getAccountVersion() {
    
        return accountVersion;
    }

    public void setAccountVersion(Integer accountVersion) {
    
        this.accountVersion = accountVersion;
    }
}

==> service-common-2.21.1-20170313.084857-8-sources.jar: com/baijia/tianxiao/dto/mobile/AppAuthToken.java <==
package com.baijia.tianxiao.dto.mobile;

import com.baijia.tianxiao.dto.BaseDto;

/**
 * app登录token
 * 
 * @title AppAuthToken
 * @desc TODO
 * @author zhangbing
 * @date 2015年4月18日
 * @version 1.0
 */
public class AppAuthToken extends BaseDto {

    private static final long serialVersionUID = -8364142680639211438L;

    private Long user_id;

    private Integer ct;

    private String salt;

    private Integer tx_cascade_user_id;

    private Integer tx_account_id;

    private Integer tx_from_org_id;

    private Integer tx_visitor_id;

    private Integer accountVersion;

    private String appEnv;

    private Integer from_master;

    public String getAppEnv() {
        return appEnv;
    }

    public void setAppEnv(String appEnv) {
        this.appEnv = appEnv;
    }

    public Long getUser_id() {
        return user_id;
    }

    public void setUser_id(Long user_id) {
        this.user_id = user_id;
    }

    public Integer getCt() {
        return ct;
    }

    public void setCt(Integer ct) {
        this.ct = ct;
    }

    public String getSalt() {
        return salt;
    }

    public void setSalt(String salt) {
        this.salt = salt;
    }

    public Integer getTx_cascade_user_id() {

        return tx_cascade_user_id;
    }

    public void setTx_cascade_user_id(Integer tx_cascade_user_id) {

        this.tx_cascade_user_id = tx_cascade_user_id;
    }

    public Integer getTx_account_id() {

        return tx_account_id;
    }

    public void setTx_account_id(Integer tx_account_id) {

        this.tx_account_id = tx_account_id;
    }

    public Integer getAccountVersion() {

        return accountVersion;
    }

    public void setAccountVersion(Integer accountVersion) {

        this.accountVersion = accountVersion;
    }

    public Integer getTXFrom_org_id() {
        return tx_from_org_id;
    }

    public void setTXFrom_org_id(Integer from_org_id) {
        this.tx_from_org_id = from_org_id;
    }

    public Integer getTx_visitor_id() {
        return tx_visitor_id;
    }

    public void setTx_visitor_id(Integer tx_visitor_id) {
        this.tx_visitor_id = tx_visitor_id;
    }

    public Integer get_From_master() {
        return this.from_master;
    }

    public void set_From_master(Integer fromMaster) {
        this.from_master = fromMaster;
    }

}
